@@ -14,11 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Unit Tests for service class
-"""
-
-from __future__ import print_function
+"""Unit Tests for service class"""
 
 import logging
 import multiprocessing
@@ -27,10 +23,10 @@ import signal
 import socket
 import time
 import traceback
+from unittest import mock
 
 import eventlet
 from eventlet import event
-import mock
 from oslotest import base as test_base
 
 from oslo_service import service
@@ -227,7 +223,7 @@ class ServiceLauncherTest(ServiceTestBase):
 
         os.kill(start_workers[0], signal.SIGHUP)
         # Wait at most 5 seconds to respawn a worker
-        cond = lambda: start_workers == self._get_workers()
+        cond = lambda: start_workers != self._get_workers()
         timeout = 5
         self._wait(cond, timeout)
 
@@ -385,6 +381,9 @@ class LauncherTest(base.ServiceBaseTestCase):
         for num_workers in [0, -1]:
             self.assertRaises(ValueError, service.launch, self.conf,
                               svc, num_workers)
+        for num_workers in ["0", "a", "1"]:
+            self.assertRaises(TypeError, service.launch, self.conf,
+                              svc, num_workers)
 
     @mock.patch('signal.alarm')
     @mock.patch('oslo_service.service.ProcessLauncher.launch_service')
@@ -638,13 +637,19 @@ class EventletServerProcessLauncherTest(base.ServiceBaseTestCase):
 
     def run_server(self):
         queue = multiprocessing.Queue()
+        # NOTE(bnemec): process_time of 5 needs to be longer than the graceful
+        # shutdown timeout in the "exceeded" test below, but also needs to be
+        # shorter than the timeout in the regular graceful shutdown test.
         proc = multiprocessing.Process(target=eventlet_service.run,
                                        args=(queue,),
-                                       kwargs={'workers': self.workers})
+                                       kwargs={'workers': self.workers,
+                                               'process_time': 5})
         proc.start()
 
         port = queue.get()
         conn = socket.create_connection(('127.0.0.1', port))
+        # Send request to make the connection active.
+        conn.sendall(b'GET / HTTP/1.1\r\nHost: localhost\r\n\r\n')
 
         # NOTE(blk-u): The sleep shouldn't be necessary. There must be a bug in
         # the server implementation where it takes some time to set up the
@@ -673,10 +678,14 @@ class EventletServerProcessLauncherTest(base.ServiceBaseTestCase):
         # connected.
         os.kill(proc.pid, signal.SIGTERM)
 
-        # server with graceful shutdown must wait forewer if
+        # server with graceful shutdown must wait forever if
         # option graceful_shutdown_timeout is not specified.
-        # we can not wait forever ... so 3 seconds are enough
-        time.sleep(3)
+        # we can not wait forever ... so 1 second is enough.
+        # NOTE(bnemec): In newer versions of eventlet that drop idle
+        # connections, this needs to be long enough to allow the signal
+        # handler to fire but short enough that our request doesn't complete
+        # or the connection will be closed and the server will stop.
+        time.sleep(1)
 
         self.assertTrue(proc.is_alive())
 
